from django.db import models

from image.models import Disk


class BaseTemplate(models.Model):

    """Virtual machine template.
    """

    name = models.CharField(
        max_length=100,
        verbose_name="name",
        help_text="Human readable name of template."
    )
    description = models.TextField(
        verbose_name="description",
        blank=True,
        help_text="Description of the template."
    )
    remote_ID = models.CharField(
        max_length=40,
        unique=True,
        verbose_name="remote_ID",
        help_text="ID, which helps access the template."
    )
    created_at = models.DateTimeField(
        auto_now_add=True,
        editable=False,
        help_text="Date, when the template created."
    )
    # owner = models.ForeignKey(User)


class Template(BaseTemplate):
    disk = models.ForeignKey(
        Disk,
        related_name="templates",
        on_delete=models.CASCADE,
        help_text="The disk where the template is located."
    )


# class PureTemplate(BaseTemplate):
#     images = modesl.ForeignKey(
#         Image,
#         related_name="templates",
#         on_delete=models.CASCADE
#     )
